@@ -18,7 +18,7 @@
 ##'     project's
 ##'     \href{https://gdal.org/programs/gdal_translate.html}{gdal_translate
 ##'     documentation} for details.
-##' @param a_srs,a_coord_epoch,a_ullr,a_nodata,a_scale,a_offset, See
+##' @param a_srs,a_coord_epoch,a_ullr,a_nodata,a_scale,a_offset See
 ##'     the GDAL project's
 ##'     \href{https://gdal.org/programs/gdal_translate.html}{gdal_translate
 ##'     documentation} for details.
@@ -27,7 +27,7 @@
 ##'     band are also allowed. See the GDAL project's
 ##'     \href{https://gdal.org/programs/gdal_translate.html}{gdal_translate
 ##'     documentation} for details.
-##' @param mo,co,nogcp,gcp,q,sds,stats,norat,noxmp,oo,sd_index,config
+##' @param mo,co,nogcp,gcp,q,sds,stats,norat,noxmp,oo,sd_index
 ##'     See the GDAL project's
 ##'     \href{https://gdal.org/programs/gdal_translate.html}{gdal_translate
 ##'     documentation} for details.
@@ -35,6 +35,10 @@
 ##'     instead of executing the requested call to GDAL, the function
 ##'     will print the command-line call that would produce the
 ##'     equivalent output.
+##' @param config_options A named character vector with GDAL config
+##'     options, of the form \code{c(option1=value1, option2=value2)}. (See
+##'     \href{https://gdal.org/user/configoptions.html}{here} for a
+##'     complete list of supported config options.)
 ##' @return Silently returns path to \code{dst_dataset}.
 ##' @export
 ##' @author Joshua O'Brien
@@ -84,7 +88,8 @@ gdal_translate <-
              srcwin, projwin, projwin_srs, srs, epo, eco, a_srs,
              a_coord_epoch, a_ullr, a_nodata, a_scale, a_offset,
              colorinterp, mo, co, nogcp, gcp, q, sds, stats, noxmp,
-             norat, oo, sd_index, config, dryrun = FALSE)
+             norat, oo, sd_index,
+             config_options = character(0), dryrun = FALSE)
 {
     ## First, handle any colorinterp_XX arguments
     dots <- list(...)
@@ -95,7 +100,7 @@ gdal_translate <-
     ## Unlike `as.list(match.call())`, forces eval of arguments
     nms <- setdiff(names(match.call())[-1], names(CI))
     args <-  mget(nms)
-    args[c("src_dataset", "dst_dataset", "dryrun")] <- NULL
+    args[c("src_dataset", "dst_dataset", "config_options", "dryrun")] <- NULL
     formalsTable <- getFormalsTable("gdal_translate")
     opts <- process_args(args, formalsTable)
 
@@ -107,6 +112,10 @@ gdal_translate <-
         return(x)
     }
 
-    gdal_utils("translate", src_dataset, dst_dataset, opts)
+    gdal_utils("translate",
+               source = src_dataset,
+               destination = dst_dataset,
+               options = opts,
+               config_options = config_options)
     invisible(dst_dataset)
 }
